@@ -81,16 +81,13 @@ def main(ndu_gate_config_file):
             if platform.system() == "Darwin":
                 ndu_gate_config_dir + "logs_macosx.conf"
 
-            logging.config.fileConfig(logging_config_file, disable_existing_loggers=False)
+            #logging.config.fileConfig(logging_config_file, disable_existing_loggers=False)
         except Exception as e:
             print(e)
             NDULoggerHandler.set_default_handler()
 
         global log
         log = logging.getLogger('service')
-        #TEMP LOGGER
-        #os.chmod("C:\\Users\\emre\\Documents\\GitHub\\ndu-gate\\ndu_gate_camera\\logs\\example.log", 0o777)
-        #logging.basicConfig(filename='C:\\Users\\emre\\Documents\\GitHub\\ndu-gate\\ndu_gate_camera\\logs\\example.log')
         log.info("NDUCameraService starting...")
         log.info("NDU-Gate logging config file: %s", logging_config_file)
         log.info("NDU-Gate logging service level: %s", log.level)
